@@ -73,7 +73,7 @@ class LayerToken:
 
 
 def read_layer_token(token):
-    if len(token) != 154:
+    if len(token) < 152:
         return None
     user_id = token[0:32]
     layer_id = token[32:64]
