@@ -358,6 +358,24 @@ class SystemClient:
         else:
             return self._post(endpoint, data, **kwargs)
 
+    # Node
+
+    def get_node(self, node: any, **kwargs) -> any:
+        endpoint = self._build_url(f'node/get')
+        return self._post(endpoint, {
+            'node': node,
+        }, **kwargs)
+
+    def put_node(self, node: any, value: any, access_name: str, **kwargs) -> any:
+        layer_id = self.__fetch_layer_id(access_name)
+
+        endpoint = self._build_url(f'node/put')
+        return self._post(endpoint, {
+            'node': node,
+            'value': value,
+            'layer': layer_id,
+        }, **kwargs)
+
     # Resource
 
     def get_resource_instance(self, resource: ResourceInstance, **kwargs):
