@@ -1,5 +1,5 @@
 from src.vyze import ServiceClient
-from src.vyze.tests.test_client import service_url
+from src.vyze.tests.test_system import service_url
 
 
 def test_service__resolve_universe():
